@@ -3,6 +3,8 @@ from django.db import models
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext as _
 
+from .settings import POPUP_LIST_TEMPLATES
+
 
 class PopupPluginModel(CMSPlugin):
     display_delay = models.IntegerField(_("Display after X seconds"), default=0)
@@ -10,6 +12,13 @@ class PopupPluginModel(CMSPlugin):
         _("Allow the popup to be reopened if it is closed"), default=False
     )
 
+    popup_template = models.CharField(
+        verbose_name=_("Popup style"),
+        choices=POPUP_LIST_TEMPLATES,
+        max_length=300,
+        blank=False,
+    )
+
     def get_page_url(self):
         try:
             # thx https://stackoverflow.com/a/47953774/6813732
